﻿Fluke Calibration                                           MET/CAL Procedure
=============================================================================
INSTRUMENT:            Sub Tek MDO4000 DANL Test VISA
DATE:                  2018-03-16 12:27:06
AUTHOR:                Fluke
REVISION:              $Revision: 23114 $
ADJUSTMENT THRESHOLD:  70%
NUMBER OF TESTS:       3
NUMBER OF LINES:       98
=============================================================================
#
#  Procedure Author:
#        CAD
#
#  Models covered:
#        MDO4014-3, MDO4034-3, MDO4054-3, MDO4054-6, MDO4104-3, MDO4104-6
#
#  Compatibility:
#        MET/CAL version 7.3.38 or later
#
#  This procedure is intended for use with MET/CAL® calibration software;
#  the terms and conditions set forth in your MET/CAL license apply to this
#  procedure.
#
#  Due to Fluke's policy of continuously updating our products, this procedure
#  may contain minor differences in methods used and/or specifications to
#  those found in the manual or other documentation. While every effort has
#  been made to ensure that this procedure is accurate, Fluke cannot be held
#  responsible for the consequences of error or omissions found within this
#  procedure.
#
#  The copyright in this procedure is owned by Fluke Corporation.
#
 STEP    FSC    RANGE NOMINAL        TOLERANCE     MOD1        MOD2  3  4 CON

  1.001  MATH         FreqRange = @Start & " to " & @Stop
  1.002  HEAD         -2 [V FreqRange]
# Store all frequency values to be used in base units (Hz)
  1.003  MATH         Start = BASE(@Start); Stop = BASE(@Stop)
# Calculate lower limit of -200 dBm.
  1.004  MATH         L[1] = 200 + @Limit

  1.005  JMPL         CONTINUE
  1.006  EVAL   Force connection message on Repeat/Cancel.
  2.001  MATH         @Connected = ""; @Time = ""
  2.002  CALL         Sub Tek MDO4000 Check and Display Connection
  2.003  LABEL        CONTINUE

# Uncertainty is the DUT Level Measurement Uncertainty.
  2.004  MATH         MEM = @Limit
  2.005  ACC          dBm/Hz         1.00U                                 +W
  2.006  TARGET       -m
  2.007  VISA         MARKER:MANUAL OFF
  2.008  VISA         RF:START [V Start];STOP [V Stop]
  2.009  CALL         Sub Tek MDO/MSO/DPO Wait for OPC VISA
  2.010  JMPL         END                          @Abort
  2.011  VISA         ACQUIRE:STATE ON
  2.012  CALL         Sub Tek MDO/MSO/DPO Wait for OPC VISA
  2.013  JMPL         END                          @Abort
# Wait 500 ms for the DUT to locate peak marker amplitude.
  2.014  VISA         [D500]MARKER:REFERENCE:FREQUENCY?[I]
  2.015  MATH         NoisePeakHz = MEM

  2.016  VISA         MARKER:MANUAL ON
  2.017  VISA         MARKER:M1:FREQUENCY:ABSOLUTE [V NoisePeakHz]
  2.018  CALL         Sub Tek MDO/MSO/DPO Wait for OPC VISA
  2.019  JMPL         END                          @Abort
  2.020  VISA         [D500]MARKER:M1:NOISEDENSITY?[I]

# Zoom in on the noise peak and measure, as necessary for range.
  2.021  IF           NOT(EMPTY(@Span))
  2.022  MATH         Span = BASE(@Span)
  2.023  VISA         RF:SPAN [V Span];FREQUENCY [V NoisePeakHz]
  2.024  CALL         Sub Tek MDO/MSO/DPO Wait for OPC VISA
  2.025  JMPL         END                          @Abort
  2.026  VISA         ACQUIRE:STATE ON
  2.027  CALL         Sub Tek MDO/MSO/DPO Wait for OPC VISA
  2.028  JMPL         END                          @Abort
# Move manual marker to center frequency.
  2.029  VISA         MARKER:M1:FREQUENCY:ABSOLUTE [V NoisePeakHz]
  2.030  CALL         Sub Tek MDO/MSO/DPO Wait for OPC VISA
  2.031  JMPL         END                          @Abort
  2.032  VISA         [D500]MARKER:M1:NOISEDENSITY?[I]
  2.033  ENDIF

# Allow manual identification of the noise threshold if the marker search
# found a spur.
  2.034  IF           MEM > @Limit
  2.035  PIC          mdo4000_danl_meas.png
  2.036  VISA         MARKER:M1:NOISEDENSITY?[I]
  2.037  ENDIF

  2.038  TSET         TDESC = [V FreqRange]; UUT_RES = 0.01
  2.039  MATH         MEM1 = @Limit
  2.040  MEMCX        dBm/Hz         -L1U

  3.001  LABEL        END
  3.002  END
